@@ -48,7 +48,7 @@ from pip.log import logger
 from pip.req import parse_requirements
 
 
-__version__ = 1, 0, 1
+__version__ = 1, 0, 2
 
 
 ITS_FINE_ITS_FINE = 0
@@ -162,7 +162,7 @@ def version_of_download(filename, package_name):
         # Since we know the project_name, we can strip that off the left, strip
         # any archive extensions off the right, and take the rest as the
         # version.
-        extensions = ['.tar.gz', '.tgz', '.tar', '.zip']
+        extensions = ['.tar.bz2', '.tar.gz', '.tgz', '.tar', '.zip']
         for ext in extensions:
             if filename.endswith(ext):
                 filename = filename[:-len(ext)]
